@@ -3,6 +3,7 @@
  *              to appear under /media
  *
  * (c) 2006 Scott Balneaves, Martin Pitt
+ * (c) 2008 Vagrant Cascadian
  *
  * This software is distributed under the terms and conditions of the
  * GNU General Public License. See file GPL for the full text of the license.
@@ -99,7 +100,7 @@ int is_mounted(char *path)
 
 void mkdir_safe(char *dir)
 {
-    if (mkdir(dir, 0755)) {
+    if (mkdir(dir, 0750)) {
         if (errno == EEXIST) {
             /* OK, we've been told that this already exists.  Make sure
              * nothing's mounted on top of it, so we aren't doing something
@@ -138,7 +139,7 @@ int root_mounter(const char *path1, const char *path2)
         }
         /* Statically build command line to prevent monkey business */
         if (path2)
-            execle(mountprog, mountprog, "--bind", path1, path2, NULL,
+            execle(mountprog, mountprog, "--move", path1, path2, NULL,
                    null_env);
         else
             execle(umountprog, umountprog, path1, NULL, null_env);
@@ -247,10 +248,10 @@ int main(int argc, char **argv)
     snprintf(ltspfsmount, sizeof(ltspfsmount), "%s%s%s%s",
              ltspfsdir1, pwent->pw_name, ltspfsdir2, mountpoint);
 
-    if (!is_mounted(ltspfsmount))
-        exit(1);
-
     if (!umount) {
+        if (!is_mounted(ltspfsmount))
+            exit(1);
+
         /* OK, name's a normal size, and looks valid. Begin creating the media
          * mount point. First, we need to create /media/uid */
 
